@@ -20,8 +20,6 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: bind.c,v 1.77 2006/11/29 20:57:02 rrt Exp $	*/
-
 #include "config.h"
 
 #include <assert.h>
@@ -161,7 +159,7 @@ static astr make_completion(size_t *keys, size_t numkeys)
 
   for (i = 0; i < numkeys; i++) {
     if (i > 0) {
-      astr_cat_cstr(as, " ");
+      astr_cat_char(as, ' ');
       len++;
     }
     key = chordtostr(keys[i]);
@@ -169,7 +167,7 @@ static astr make_completion(size_t *keys, size_t numkeys)
     astr_delete(key);
   }
 
-  return astr_cat_cstr(as, "-");
+  return astr_cat_char(as, '-');
 }
 
 static leafp completion_scan(size_t key, size_t **keys, size_t *numkeys)
