@@ -39,23 +39,18 @@
 #include "getopt.h"
 #endif
 #include <signal.h>
-#if ALLEGRO
-#if HAVE_ALLEGRO_H
-#include <allegro.h>
-#endif
-#endif
 
 #include "zile.h"
 #include "extern.h"
 #include "eval.h"
 #include "vars.h"
 
-#define ZILE_VERSION_STRING	"Zile " VERSION
+#define ZILE_VERSION_STRING	PACKAGE_NAME " " VERSION
 
 #define ZILE_COPYRIGHT_STRING \
   "Copyright (C) 1997-2004 Sandro Sigala <sandro@sigala.it>\n"\
   "Copyright (C) 2003-2007 Reuben Thomas <rrt@sc3d.org>\n"\
-  "Copyright (C) 2003-2004 David A. Capello <dacap@users.sourceforge.net>"
+  "Copyright (C) 2004 David A. Capello <dacap@users.sourceforge.net>"
 
 /* The current window; the first window in list. */
 Window *cur_wp = NULL, *head_wp = NULL;
@@ -102,10 +97,10 @@ static char about_splash_str[] = "\
 \n\
 " ZILE_COPYRIGHT_STRING "\n\
 \n\
-Type `C-x C-c' to exit Zile.\n\
+Type `C-x C-c' to exit " PACKAGE_NAME ".\n\
 Type `C-h h' for help; `C-x u; to undo changes.\n\
 Type `C-h C-d' for information on getting the latest version.\n\
-Type `C-h t' for a tutorial on using Zile.\n\
+Type `C-h t' for a tutorial on using " PACKAGE_NAME ".\n\
 Type `C-h s' for a sample configuration file.\n\
 Type `C-g' at any time to cancel the current operation.\n\
 \n\
@@ -117,7 +112,7 @@ Combinations like `C-h h' mean first press `C-h', then `h'.\n\
 ";
 
 static char about_minibuf_str[] =
-"Welcome to Zile!  For help type `C-h h'";
+"Welcome to " PACKAGE_NAME "!  For help type `C-h h'";
 
 static void about_screen(void)
 {
@@ -182,14 +177,14 @@ then enter the text in that file's own buffer.\n\
 static void segv_sig_handler(int signo)
 {
   (void)signo;
-  fprintf(stderr, "Zile crashed.  Please send a bug report to <" PACKAGE_BUGREPORT ">.\r\n");
+  fprintf(stderr, PACKAGE_NAME " crashed.  Please send a bug report to <" PACKAGE_BUGREPORT ">.\r\n");
   zile_exit();
 }
 
 static void other_sig_handler(int signo)
 {
   (void)signo;
-  fprintf(stderr, "Zile terminated with signal %d.\r\n", signo);
+  fprintf(stderr, PACKAGE_NAME " terminated with signal %d.\r\n", signo);
   zile_exit();
 }
 
@@ -220,6 +215,7 @@ int main(int argc, char **argv)
   int c, bflag = FALSE, qflag = FALSE;
   astr ms = NULL;
   list fargs = list_new();
+  size_t line;
 
   /* Set up Lisp environment now so it's available to files and
      expressions specified on the command-line. */
@@ -252,24 +248,24 @@ int main(int argc, char **argv)
       fprintf(stderr,
               ZILE_VERSION_STRING "\n"
               ZILE_COPYRIGHT_STRING "\n"
-              "Zile comes with ABSOLUTELY NO WARRANTY.\n"
-              "You may redistribute copies of Zile\n"
+              PACKAGE_NAME " comes with ABSOLUTELY NO WARRANTY.\n"
+              "You may redistribute copies of " PACKAGE_NAME "\n"
               "under the terms of the GNU General Public License.\n"
               "For more information about these matters, see the file named COPYING.\n"
               );
       return 0;
     case 'h':
       fprintf(stderr,
-              "Usage: zile [OPTION-OR-FILENAME]...\n"
+              "Usage: " PACKAGE " [OPTION-OR-FILENAME]...\n"
               "\n"
-              "Run Zile, the lightweight Emacs clone.\n"
+              "Run " PACKAGE_NAME ", the lightweight Emacs clone.\n"
               "\n"
               "Initialization options:\n"
               "\n"
               "--batch                do not do interactive display; implies -q\n"
               "--help                 display this help message and exit\n"
-              "--funcall, -f FUNC     call Zile function FUNC with no arguments\n"
-              "--no-init-file, -q     do not load ~/.zile\n"
+              "--funcall, -f FUNC     call " PACKAGE_NAME " function FUNC with no arguments\n"
+              "--no-init-file, -q     do not load ~/." PACKAGE "\n"
               "--version              display version information and exit\n"
               "\n"
               "Action options:\n"
@@ -283,7 +279,7 @@ int main(int argc, char **argv)
         ms = astr_afmt(astr_new(), "Unknown option `%s'", argv[this_optind]);
       break;
     case ':':                   /* Missing argument */
-      fprintf(stderr, "zile: Option `%s' requires an argument\n\n", argv[this_optind]);
+      fprintf(stderr, PACKAGE ": Option `%s' requires an argument\n\n", argv[this_optind]);
       exit(1);
     }
   }
@@ -313,7 +309,7 @@ int main(int argc, char **argv)
       le *list;
 
       astr as = get_home_dir();
-      astr_cat_cstr(as, "/.zile");
+      astr_cat_cstr(as, "/." PACKAGE);
       list = lisp_read_file(astr_cstr(as));
       astr_delete(lisp_dump(list));
       astr_delete(as);
@@ -323,26 +319,19 @@ int main(int argc, char **argv)
     /* Reinitialise the scratch buffer to catch settings */
     init_buffer(cur_bp);
 
-    if (argc >= 1) {
-      while (*argv) {
-        size_t line = 1;
-        if (**argv == '+')
-          line = strtoul(*argv++ + 1, NULL, 10);
-        if (*argv) {
-          astr as = astr_new();
-
-          astr_cpy_cstr(as, *argv);
-
-          find_file(astr_cstr(as));
-          argv++;
-          astr_delete(as);
-
-          if (line > 1)
-            ngotodown(line - 1);
-          lastflag |= FLAG_NEED_RESYNC;
-        }
+    /* Open files given on the command line */
+    for (line = 1; *argv; argv++) {
+      if (**argv == '+')
+        line = strtoul(*argv + 1, NULL, 10);
+      else {
+        find_file(*argv);
+        ngotodown(line - 1);
+        line = 1;
+        lastflag |= FLAG_NEED_RESYNC;
       }
-    } else if (list_length(fargs) == 0)
+    }
+
+    if (argc == 0 && list_length(fargs) == 0)
       /* Show the splash screen only if no files and no Lisp expression
          or load file is specified on the command line. */
       about_screen();
@@ -354,7 +343,7 @@ int main(int argc, char **argv)
     execute_functions(fargs);
     list_delete(fargs);
 
-    /* Run the main Zile loop. */
+    /* Run the main loop. */
     loop();
 
     /* Tidy and close the terminal. */
